@@ -2,7 +2,7 @@ import logging
 from mkdocs.utils import warning_filter
 
 # Set up a logger for my code to use
-LOGGER = logging.getLogger(f"mkdocs.plugins.badges")
+LOGGER = logging.getLogger("mkdocs.plugins.badges")
 LOGGER.addFilter(warning_filter)
 
 def warning(message: str) -> None:
@@ -12,3 +12,5 @@ def warning(message: str) -> None:
 # from .utils import replace_regex_matches
 # from .normal_badge import replace_normal_badges
 from .plugin import BadgesPlugin
+
+__all__ = ["BadgesPlugin"]
